#!/usr/bin/perl

=head1 TITLE

example - example program for this

=cut


use Gtk2::Ex::Getopt;

use Pod::Usage;
use Pod::Simple::Text;


my %opts=();

# types CheckButton, Entry, Combo (takes array of values), FileOpen, FileSave, SpinButton
# an Entry can be hidden

# Gtk2::Ex::Getopt::GetOptions(\%opts,  # the title is optional - if no title it will use the executable name
Gtk2::Ex::Getopt::GetOptions(\%opts, "What an Example!",
    ["s=s", "Looking for a string.", ], 
    ["i=i", 'Looking for an integer.',
            required => 1,
    ],
    ["o=o", "extended perl style integer - (really?)" ], 
    ["f=f","Floating Point",
            required => 1,
    ],
    ["n","Nothing really"],
    ["z:s","Really nothing"],
    ["nolabel", ""],
    ["", "Required Filename",
        type => 'BeginGroup'
    ],
    ["", "file to read in",
        type => 'FileOpen',
        required => 1,
        var => sub { push @ARGV, $_[0]; },
    ],
    ["", "",
        type => 'EndGroup'
    ],
    ["h|?|help", "!GUI" ],
    ["full-help|fullhelp","!GUI"],

    ["", "Help",
        type => 'Button',
        run => sub
            { 
                $parser = Pod::Simple::Text->new();
                $parser->output_string( \$string );
                $parser->parse_file($0);
                Gtk2::Ex::Getopt::textWindow($string);
            }
    ],
    );

=head1 SYNOPSIS

  example -s string -i 1 -o -f 2.1 filename
  example -h
  example --full-help

Example of how to use Getopt::GUI::Long

=head1 OPTIONS

  -h                short help
  --full-help       full help

  -s string         Blah Blah Blah 
  -i integer        Blah Blah Blah (required)
  -f float          Blah blah blah blah blah (required)
  -o integer        blah blah blah blah blah 
  -n                blah blah blah blah blah 
  -z                blah blah blah blah blah 
  -e something
  -c <one|two|3|4>
  -k 
  -p value
  --file filename
  --open filename
  -z

  filename          File name to read in

=cut


print "Output flags:\n";
foreach my $key (keys(%opts)) {
    printf "%-20s => %s\n", $key, $opts{$key};
}

print "ARGV[0]: ". $ARGV[0]."\n";
print "usingvarref: ". $usingvarref."\n";


if ($opts{'full-help'})
{
    pod2usage( -verbose => 2);
    exit;
}

#if ( defined $opts{h} || not (defined $ARGV[0] && defined $opts{c}) )
if ( defined $opts{h} || not (defined $ARGV[0]) )
{
    pod2usage(1);
    exit;
}

print "This is the end of the program - should we be here?\n";


__END__

=head1 DESCRIPTION

Blah blah blah blah blah blah blah, blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah, blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah C<blah>.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.  Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.  Blah blah blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=over 4

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.  Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.  Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.

  Blah blah blah blah blah blah blah blah blah.
 
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=back

=head2 blahblahblah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=head2 blah blah blah blah 

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=over 8

=item blahblah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

    Blah blah blah blah blah blah blah blah blah.
    Blah blah blah blah blah blah blah blah blah.
    Blah blah blah blah blah blah blah blah blah.
    Blah blah blah blah blah blah blah blah blah.

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=back

=head2 blah

Blah blah blah blah blah blah blah blah blah.

=over 8

=item blah

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item blahjjj

Blah blah blah blah blah blah blah blah blah.

=over 8

=item blah

Blah blah blah blah blah blah blah blah blah.

=item blahjjj

Blah blah blah blah blah blah blah blah blah.

=item blah

Blah blah blah blah blah blah blah blah blah.

=back

=over 8

=item .

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=item .

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=back

=begin comment

Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.
Blah blah blah blah blah blah blah blah blah.

=end comment
