package Gtk2::Ex::Getopt::Base;

sub new
{
    my ($class, $params) = @_;
    my ($self) = {%$params};
    bless $self, ref $class || $class;

    return $self;
}

sub query
{}

sub gtk
{
    my ($self) = @_;
    return $self->{'gtk'};
}

package Gtk2::Ex::Getopt::CheckButton;

use Gtk2;
use base 'Gtk2::Ex::Getopt::Base';

sub new
{
    my ($class, $params) = @_;
    my ($self) = $class->SUPER::new($params);
    my ($gtk) = Gtk2::CheckButton->new();
    $self->{'gtk'} = $gtk;
    return $self;
}

sub query
{
    my ($self) = @_;

    return $self->{'gtk'}->get_active;
}

package Gtk2::Ex::Getopt::Entry;

use Gtk2;
use base 'Gtk2::Ex::Getopt::Base';

sub new
{
    my ($class, $params) = @_;
    my ($self) = $class->SUPER::new($params);
    my ($gtk) = Gtk2::Entry->new();
    $self->{'gtk'} = $gtk;

    if ($self->{'maxsize'})
    { $gtk->set_max_length($self->{'maxsize'}); }

    if ($self->{'size'})
    { $gtk->set_width_chars($self->{'size'}); }

    if ($self->{'hidden'})
    {
        $gtk->set_invisible_char('*');
        $gtk->set_visibility(FALSE);
    }
    return $self;
}

sub query
{
    my ($self) = @_;

    return $self->{'gtk'}->get_text();
}


package Gtk2::Ex::Getopt::Combo;

use Gtk2;
use base 'Gtk2::Ex::Getopt::Base';

sub new
{
    my ($class, $params) = @_;
    my ($self) = $class->SUPER::new($params);
    my ($gtk) = Gtk2::ComboBox->new_text();
    my ($v);
    $self->{'gtk'} = $gtk;

    foreach $v (@{$self->{'values'}})
    {
        $self->{'gtk'}->append_text($v);
    }
    return $self;
}

sub query
{
    my ($self) = @_;

    return $self->{'gtk'}->get_active_text;
}

package Gtk2::Ex::Getopt::FileOpen;

use Gtk2;
use base 'Gtk2::Ex::Getopt::Base';

sub new
{
    my ($class, $params) = @_;
    my ($self) = $class->SUPER::new($params);
    my ($gtk) = Gtk2::HBox->new();
    my ($v, $b, $e);
    $self->{'gtk'} = $gtk;
    $e = Gtk2::Entry->new();
    $b = Gtk2::Button->new('Browse...'); 
    $self->{'gtk_entry'} = $e;
    $self->{'gtk_button'} = $b;
    $gtk->pack_start_defaults($e);
    $gtk->pack_start_defaults($b);
    
    $b->signal_connect('clicked' => sub {
        my ($c) = Gtk2::FileChooserDialog->new('Open...',
            undef, 'open', 'gtk-cancel' => 'reject', 'gtk-open' => 'accept');
        my ($res);

        $c->set_filename($self->{'gtk_entry'}->get_text());
        $res = $c->run();
        if ($res eq 'accept')
        {
            $self->{'gtk_entry'}->set_text($c->get_filename());
        }
        $c->destroy();
    });

    $self;
}

sub query
{
    my ($self) = @_;
    return $self->{'gtk_entry'}->get_text();
}


package Gtk2::Ex::Getopt::FileSave;

use Gtk2;
use base 'Gtk2::Ex::Getopt::Base';

sub new
{
    my ($class, $params) = @_;
    my ($self) = $class->SUPER::new($params);
    my ($gtk) = Gtk2::HBox->new();
    my ($v, $b, $e);
    $self->{'gtk'} = $gtk;
    $e = Gtk2::Entry->new();
    $b = Gtk2::Button->new('Browse...'); 
    $self->{'gtk_entry'} = $e;
    $self->{'gtk_button'} = $b;
    $gtk->pack_start_defaults($e);
    $gtk->pack_start_defaults($b);
    
    $b->signal_connect('clicked' => sub {
        my ($c) = Gtk2::FileChooserDialog->new('SaveAs...',
            undef, 'save', 'gtk-cancel' => 'reject', 'gtk-save' => 'accept');
        my ($res);

        $c->set_filename($self->{'gtk_entry'}->get_text());
        $res = $c->run();
        if ($res eq 'accept')
        {
            $self->{'gtk_entry'}->set_text($c->get_filename());
        }
        $c->destroy();
    });

    $self;
}

sub query
{
    my ($self) = @_;
    return $self->{'gtk_entry'}->get_text();
}

package Gtk2::Ex::Getopt::SpinButton;

use Gtk2;
use base 'Gtk2::Ex::Getopt::Base';

sub new
{
    my ($class, $params) = @_;
    my ($self) = $class->SUPER::new($params);
    my ($gtk) = Gtk2::SpinButton->new_with_range($self->{'min'}, $self->{'max'} || 10000, $self->{'step'} || 1);
    $self->{'gtk'} = $gtk;
 
    return $self;
}

sub query
{
    my ($self) = @_;

    return $self->{'gtk'}->get_value_as_int;
}

1;

